==> cdktf-cdktf-provider-google-0.6.2.tar.gz: package/lib/data-google-storage-bucket.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataGoogleStorageBucketConfig extends cdktf.TerraformMetaArguments {
    /**
     * The name of the bucket.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/storage_bucket#name DataGoogleStorageBucket#name}
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export declare class DataGoogleStorageBucketCors extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get maxAgeSeconds(): number;
    /**
     * @stability stable
     */
    get method(): string[];
    /**
     * @stability stable
     */
    get origin(): string[];
    /**
     * @stability stable
     */
    get responseHeader(): string[];
}
/**
 * @stability stable
 */
export declare class DataGoogleStorageBucketEncryption extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get defaultKmsKeyName(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleStorageBucketLifecycleRuleAction extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get storageClass(): string;
    /**
     * @stability stable
     */
    get type(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleStorageBucketLifecycleRuleCondition extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get age(): number;
    /**
     * @stability stable
     */
    get createdBefore(): string;
    /**
     * @stability stable
     */
    get customTimeBefore(): string;
    /**
     * @stability stable
     */
    get daysSinceCustomTime(): number;
    /**
     * @stability stable
     */
    get daysSinceNoncurrentTime(): number;
    /**
     * @stability stable
     */
    get matchesStorageClass(): string[];
    /**
     * @stability stable
     */
    get noncurrentTimeBefore(): string;
    /**
     * @stability stable
     */
    get numNewerVersions(): number;
    /**
     * @stability stable
     */
    get withState(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleStorageBucketLifecycleRule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get action(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get condition(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class DataGoogleStorageBucketLogging extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get logBucket(): string;
    /**
     * @stability stable
     */
    get logObjectPrefix(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleStorageBucketRetentionPolicy extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get isLocked(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get retentionPeriod(): number;
}
/**
 * @stability stable
 */
export declare class DataGoogleStorageBucketVersioning extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get enabled(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class DataGoogleStorageBucketWebsite extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get mainPageSuffix(): string;
    /**
     * @stability stable
     */
    get notFoundPage(): string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/d/storage_bucket google_storage_bucket}.
 *
 * @stability stable
 */
export declare class DataGoogleStorageBucket extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/d/storage_bucket google_storage_bucket} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataGoogleStorageBucketConfig);
    /**
     * @stability stable
     */
    get bucketPolicyOnly(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    cors(index: string): DataGoogleStorageBucketCors;
    /**
     * @stability stable
     */
    get defaultEventBasedHold(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    encryption(index: string): DataGoogleStorageBucketEncryption;
    /**
     * @stability stable
     */
    get forceDestroy(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    labels(key: string): string | cdktf.IResolvable;
    /**
     * @stability stable
     */
    lifecycleRule(index: string): DataGoogleStorageBucketLifecycleRule;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    logging(index: string): DataGoogleStorageBucketLogging;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    get requesterPays(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    retentionPolicy(index: string): DataGoogleStorageBucketRetentionPolicy;
    /**
     * @stability stable
     */
    get selfLink(): string;
    /**
     * @stability stable
     */
    get storageClass(): string;
    /**
     * @stability stable
     */
    get uniformBucketLevelAccess(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get url(): string;
    /**
     * @stability stable
     */
    versioning(index: string): DataGoogleStorageBucketVersioning;
    /**
     * @stability stable
     */
    website(index: string): DataGoogleStorageBucketWebsite;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google-0.6.33.tar.gz: package/lib/data-google-storage-bucket.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleStorageBucketConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the bucket.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/storage_bucket#name DataGoogleStorageBucket#name}
    */
    readonly name: string;
}
export declare class DataGoogleStorageBucketCors extends cdktf.ComplexComputedList {
    get maxAgeSeconds(): number;
    get method(): string[];
    get origin(): string[];
    get responseHeader(): string[];
}
export declare class DataGoogleStorageBucketEncryption extends cdktf.ComplexComputedList {
    get defaultKmsKeyName(): string;
}
export declare class DataGoogleStorageBucketLifecycleRuleAction extends cdktf.ComplexComputedList {
    get storageClass(): string;
    get type(): string;
}
export declare class DataGoogleStorageBucketLifecycleRuleCondition extends cdktf.ComplexComputedList {
    get age(): number;
    get createdBefore(): string;
    get customTimeBefore(): string;
    get daysSinceCustomTime(): number;
    get daysSinceNoncurrentTime(): number;
    get matchesStorageClass(): string[];
    get noncurrentTimeBefore(): string;
    get numNewerVersions(): number;
    get withState(): string;
}
export declare class DataGoogleStorageBucketLifecycleRule extends cdktf.ComplexComputedList {
    get action(): cdktf.IResolvable;
    get condition(): cdktf.IResolvable;
}
export declare class DataGoogleStorageBucketLogging extends cdktf.ComplexComputedList {
    get logBucket(): string;
    get logObjectPrefix(): string;
}
export declare class DataGoogleStorageBucketRetentionPolicy extends cdktf.ComplexComputedList {
    get isLocked(): cdktf.IResolvable;
    get retentionPeriod(): number;
}
export declare class DataGoogleStorageBucketVersioning extends cdktf.ComplexComputedList {
    get enabled(): cdktf.IResolvable;
}
export declare class DataGoogleStorageBucketWebsite extends cdktf.ComplexComputedList {
    get mainPageSuffix(): string;
    get notFoundPage(): string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google/d/storage_bucket google_storage_bucket}
*/
export declare class DataGoogleStorageBucket extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google/d/storage_bucket google_storage_bucket} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleStorageBucketConfig
    */
    constructor(scope: Construct, id: string, config: DataGoogleStorageBucketConfig);
    get bucketPolicyOnly(): cdktf.IResolvable;
    cors(index: string): DataGoogleStorageBucketCors;
    get defaultEventBasedHold(): cdktf.IResolvable;
    encryption(index: string): DataGoogleStorageBucketEncryption;
    get forceDestroy(): cdktf.IResolvable;
    get id(): string;
    labels(key: string): string | cdktf.IResolvable;
    lifecycleRule(index: string): DataGoogleStorageBucketLifecycleRule;
    get location(): string;
    logging(index: string): DataGoogleStorageBucketLogging;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get project(): string;
    get requesterPays(): cdktf.IResolvable;
    retentionPolicy(index: string): DataGoogleStorageBucketRetentionPolicy;
    get selfLink(): string;
    get storageClass(): string;
    get uniformBucketLevelAccess(): cdktf.IResolvable;
    get url(): string;
    versioning(index: string): DataGoogleStorageBucketVersioning;
    website(index: string): DataGoogleStorageBucketWebsite;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
